﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.ServiceModel;
using System.Runtime.Serialization;
using System.ServiceModel.Description;
using System.ServiceModel.Channels;
using Microsoft.ServiceBus.Messaging;
using Microsoft.ServiceBus.Description;
using Microsoft.ServiceBus;
using SBV2WCFQueuesSample;


namespace WCFQueuesSample
{
    class Program
    {
        
        /* Note, to run these samples, you need an Azure Service Bus account,
        * an active Azure Service Bus namespace and an ACS V2 namespace.
        * Please go to http://Azure.com for more information on getting started.
        */

        static string issuer = "owner";
        static string key = "Your Key";
        private static Uri serviceBusEndpointAddress = new Uri("sb://YourNamespace.servicebus.windows.net/Orders");

        static void Main(string[] args)
        {

            /********************************
             *** Service and Service Host ***
             ********************************/

            NetMessagingBinding binding = new NetMessagingBinding();
            ContractDescription contract = ContractDescription.GetContract(typeof(IOrderService),typeof(OrderService));

            TransportClientEndpointBehavior transportBehavior = new TransportClientEndpointBehavior();
            transportBehavior.TokenProvider = TokenProvider.CreateSharedSecretTokenProvider(issuer, key);
            
            ServiceEndpoint endpoint = new ServiceEndpoint(contract, binding, new EndpointAddress(serviceBusEndpointAddress.AbsoluteUri));
            endpoint.Behaviors.Add(transportBehavior);

            ServiceHost host = new ServiceHost(typeof(OrderService), serviceBusEndpointAddress);
            host.AddServiceEndpoint(endpoint);

            host.Open();

          
            Console.WriteLine("Ready to process messages from Azure AppFabric Service Bus Queues");

            /********************
             *** Client Proxy ***
             ********************/

            ChannelFactory<IOrderService> factory = new ChannelFactory<IOrderService>(endpoint);
            IOrderService client = factory.CreateChannel();
          
            Order order = new Order();
            order.OrderId = 42;
            order.Products.Add("Kinect", 70.50M);
            order.Products.Add("XBOX 360", 199.99M);
            order.Total = order.Products["Kinect"] + order.Products["XBOX 360"];


            client.ProcessOrder(order);
            Console.WriteLine(String.Format("Order {0} Sent!", order.OrderId));
            factory.Close();

            Console.ReadLine();
        }
    }

   
}
